import { MongoClient } from "mongodb";

if(!import.meta.env.MONGODB_URI || !import.meta.env.MONGODB_DB) {
  throw new Error("Please define MONGODB_URI and MONGODB_DB environment variables inside .env");
}

const uri = import.meta.env.MONGODB_URI;
const dbName = import.meta.env.MONGODB_DB;
const options = {};

const connect = async () => {
    const mongo = await new MongoClient(uri, options).connect();

    return mongo.db(dbName);
}

export const getDB = async () => {
    const mongo = await connect();
    return mongo;
}

export const Users = async () => {
    const db = await getDB();
    return db.collection('users');
}

export const AccessTokens = async () => {
    const db = await getDB();
    return db.collection('accessTokens');
}