import { Users } from '../db/mongodb';
import type User from '../../types/User';
import type Resources from '../../types/Resources';
import type Building from '../../types/Building';
import type AccessToken from '../../types/AccessToken';
import { ObjectId } from 'mongodb';

export const getAllUsers = async () => {
    const users = await Users();
    return users.find({}).toArray() as Promise<User[]>;
}

export const createUser = async (user: User) => {
    const newUser = await (await Users()).insertOne(user);
    return newUser;
}

export const getUserById = async (id: ObjectId) => {
    const users = await Users();
    return users.findOne({
        _id: id
    }) as Promise<User | null>;
}

export const getUserByNickOrEmail = async (searchString: string) => {
    const users = await Users();
    return users.findOne({
        $or: [
            { username: searchString },
            { email: searchString }
        ]
    }) as Promise<User | null>;
}

export const getUserByAccessToken = async(accessToken: string | AccessToken): Promise<User | null> => {
    if(typeof accessToken === "string") {
        const userId = new ObjectId(Buffer.from(accessToken.split(".")[2], 'base64url').toString());
        return getUserById(userId);
    } else return getUserById(accessToken.user as ObjectId)
}

export const getUserBuildings = async (user: User): Promise<Array<Building>> => {
    // const users = await Users();
    // const user = await users.findOne({ username });

    const buildings: Array<Building> = [];

    if (user?.buildings !== undefined) {
        user?.buildings.forEach((building: Building) => {
            buildings.push(building);
        });
    }

    return buildings;
}

export const createOrUpgradeBuilding = async (username: string, building: Building) => {
    const users = await Users();

    const result = await users.updateOne(
        { username, "buildings.name": building.id },
        { $set: { "buildings.$.level": building.level } }
    );

    if (result.modifiedCount === 0) {
        await users.updateOne({ username },
            { $push: { buildings: building } }
        );
    }
}