import { ObjectId } from "mongodb"
import { getUserById } from "../db/users";
import { Users } from "../db/mongodb";
import type DBResource from "../../types/DBResource";
import type Resource from "../../types/Resource";

export const getUserResources = async (id: ObjectId): Promise<Array<DBResource>> => {
    const user = await getUserById(id);

    const defaultResources: Array<DBResource> = [];

    return user?.resources === undefined ? defaultResources : user?.resources;
}

export const updateUserResources = async (id: ObjectId, resources: Array<DBResource>) => {
    const users = await Users();
    await users.updateOne({ _id: id }, {
        $set: {
            resources
        }
    });
}

export const calculateCurrentAvailableResources = async (id: ObjectId): Promise<Array<Resource>> => {
    const user = await getUserById(id);

    if(user === null) return [];

    const userResources = await getUserResources(id);

    userResources.forEach(res => {
        const timeDiff = Math.abs((new Date()).getTime() - res.lastUpdated.getTime());
        const hours = timeDiff / (1000 * 60 * 60);
        const amountToAdd = hours * res.perHourMiningRate;
        res.amount += amountToAdd;
        res.lastUpdated = new Date();
    });

    updateUserResources(id, userResources);
    return userResources;
}