import { type APIRoute } from "astro";
import validateAccessToken from "../../../lib/utils/validateAccessToken";
import { getAccessToken } from "../../../lib/db/accessTokens";
import { getUserResources } from "../../../lib/db/users";
import buildings from '../../../lib/data/buildings.json';
import calculateAvailableResources from "../../../lib/utils/calculateAvailableResources";

export const POST: APIRoute = async({ request }) => {
    const response = await validateAccessToken(request);
    if(response instanceof Response) return response;

    const user = response.username;
    const resources = await getUserResources(user);
    const buildingId = (await request.json()).building;
    const building = buildings.map(cat => cat.buildings.filter(b => b.id === buildingId))[0][0];
    const balance = calculateAvailableResources(resources, building.cost);
    
    return new Response(
        JSON.stringify({
            code: 200,
            message: "OK",
            accessToken: response,
            data: {
                resources,
                building,
                balance
            }
        }), { status: 200 }
    )
}